Documentation
¶
Overview ¶
Package packman provides utilities for managing apps and packages that use the Goki framework.
Index ¶
- func AppName(pkgPath string) string
- func Build(c *config.Config) error
- func BuildDesktop(c *config.Config, platform config.Platform) error
- func GetVersion(c *config.Config) error
- func Install(c *config.Config) error
- func InstallLocal(c *config.Config) error
- func InstallLocalDesktop(pkgPath string, osName string) error
- func InstallPackage(pkg Package) error
- func Log(c *config.Config) error
- func PushGitRelease(c *config.Config) error
- func PushVersionFileGit(c *config.Config) error
- func Release(c *config.Config) error
- func ReleaseApp(c *config.Config) error
- func ReleaseLibrary(c *config.Config) error
- func Run(c *config.Config) error
- func SetVersion(c *config.Config) error
- func UpdateVersion(c *config.Config) error
- func VersionFileString(c *config.Config) (string, error)
- func VersionRelease(c *config.Config) error
- type Command
- type Commands
- type Package
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Build ¶
Build builds an executable for the package at the config path for the config platforms.
func BuildDesktop ¶ added in v0.1.21
BuildDesktop builds an executable for the config package for the given desktop platform. BuildDesktop does not check whether platforms are valid, so it should be called through Build in almost all cases.
func GetVersion ¶ added in v0.1.16
GetVersion prints the version of the project.
func Install ¶
Install installs the config package by looking for it in the list of supported packages. If the config ID is a filepath, it installs the package at that filepath on the local system. Install uses the same config info as build.
func InstallLocal ¶
InstallLocal installs a local package from the filesystem on the user's device for the config target operating systems.
func InstallLocalDesktop ¶ added in v0.1.21
InstallLocalDesktop builds and installs an executable for the package at the given path for the given desktop platform. InstallLocalDesktop does not check whether operating systems are valid, so it should be called through Install in almost all cases.
func InstallPackage ¶
InstallPackage installs the given package object.
func Log ¶
Log prints the logs from your app running on Android to the terminal. Android is the only supported platform for log; use the -debug flag on run for other platforms.
func PushGitRelease ¶
PushGitRelease commits a release commit using Git, adds a version tag, and pushes the code and tags based on the given config info.
func PushVersionFileGit ¶ added in v0.1.10
PushVersionFileGit makes and pushes a Git commit updating the version file based on the given config info. It does not actually update the version file; it only commits and pushes the changes that should have already been made by UpdateVersion.
func Release ¶
Release releases the project as a git tag. It should be called after update-version or similar.
func ReleaseLibrary ¶
ReleaseLibrary releases the config library.
func Run ¶ added in v0.1.23
Run builds and runs the config package. It also displays the logs generated by the app. It uses the same config info as build.
func SetVersion ¶ added in v0.1.13
SetVersion updates the config and version file of the config project based on the config version and commits and pushes the changes. After it, release or similar should be called to push the git tags.
func UpdateVersion ¶ added in v0.1.10
UpdateVersion updates the version of the project by one patch version. After it, release or similar should be called to push the git tags.
func VersionFileString ¶
VersionFileString returns the version file string for a project with the given config info.
func VersionRelease ¶ added in v0.1.43
VersionRelease calls update-version and then release. It is the standard release path.
Types ¶
type Package ¶
type Package struct {
ID string // the unique name of the package (ex: dev)
Name string // the user friendly name of the package (ex: The Goki Developer Tools)
InstallCommands Commands // the set of commands to run for each operating system to install the package
}
Package contains all of the information about a package.
func LoadPackages ¶
LoadPackages loads all of the packages from the packages.json file